@@ -424,7 +424,17 @@ def sunengine(ctx, accuracy=1.0, vlt=0.64, idres=32, rayargs=None,
 
 
 @main.command()
-@clk.shared_decs(engine_opts)
+@click.option('-idres', default=32,
+             help='the initial directional sampling resolution '
+                  '(as sqrt of samples per hemisphere)')
+@click.option('-t0', default=20.0,
+              help='initial sample  threshold (in cd/m^2), use instead of '
+                   'accuracy when source luminance and meaningful difference'
+                   'is known')
+@click.option('-t1', default=400.0,
+              help='final sample  threshold (in cd/m^2), use instead of '
+                   'accuracy when source luminance and meaningful difference'
+                   'is known')
 @click.option('-rayargs',
               help='additional arguments to pass to the rendering engine')
 @click.option('--default-args/--no-default-args', default=True,
@@ -446,9 +456,10 @@ def sunengine(ctx, accuracy=1.0, vlt=0.64, idres=32, rayargs=None,
                    "shades")
 @click.option("--color/--no-color", default=True)
 @clk.shared_decs(clk.command_decs(raytraverse.__version__, wrap=True))
-def sourceengine(ctx, srcfile=None, source="source", accuracy=1.0, vlt=1.0,
-                 idres=32, rayargs=None, default_args=True, nlev=6, color=True,
-                 opts=False, debug=False, version=None, **kwargs):
+def sourceengine(ctx, srcfile=None, source="source", idres=32, rayargs=None,
+                 default_args=True, nlev=6, color=True, t0=20.0, t1=400.0,
+                 opts=False, debug=False, version=None,
+                 **kwargs):
     """initialize engine for sunrun
 
     Effects:
@@ -470,8 +481,7 @@ def sourceengine(ctx, srcfile=None, source="source", accuracy=1.0, vlt=1.0,
     rtrace = Rtrace(rayargs=rayargs, scene=srcscn, default_args=default_args)
     if color:
         rtrace.update_ospec("v")
-    accuracy = accuracy*vlt/0.64
-    ptkwargs = dict(accuracy=accuracy, idres=idres, nlev=nlev, stype=source)
+    ptkwargs = dict(t0=t0, t1=t1, idres=idres, nlev=nlev, stype=source)
     ctx.obj['sourceengine'] = dict(engine=rtrace, ptkwargs=ptkwargs,
                                    source=(srcfile, source))
 
@@ -540,9 +550,10 @@ def skyrun(ctx, accuracy=1.0, nlev=3, jitter=True, overwrite=False, plotp=False,
         skyfield = skysampler.run(pm, plotp=plotp, pfish=False)
         try_mkdir(f"{scn.outdir}/{pm.name}")
         reflf = f"{scn.outdir}/{pm.name}/reflection_normals.txt"
-        refl = scn.reflection_search(skyfield.vecs)
-        if refl.size > 0:
-            np.savetxt(reflf, refl)
+        if not os.path.isfile(reflf):
+            refl = scn.reflection_search(skyfield.vecs)
+            if refl.size > 0:
+                np.savetxt(reflf, refl)
     else:
         if scn.dolog:
             click.echo(f"Sky Lightfield reloaded from {scn.outdir}/{pm.name} "
@@ -752,7 +763,7 @@ rows in wea/epw file using space seperated list or python range notation:
  click.option("-simtype", default="3comp",
               help=f"simulation process/integration type:\n\n"
                    f"{api.stypedocstring}\n\nor source name (overrides "
-                   f"--rresampleview, --directview, etc."),
+                   f"--resampleview, --directview, etc."),
  click.option("-resuntol", default=1.0,
               help="tolerance for resampling sun views"),
  click.option("-resamprad", default=0.0,
@@ -778,13 +789,16 @@ rows in wea/epw file using space seperated list or python range notation:
                    "where pidx, vidx refer to the order of points, and vm.")
 @click.option("-basename", default="results",
               help="prefix of namebyindex.")
+@click.option("-bandwidth", default=20,
+              help="used by interpolation.")
 @click.option("--directview/--no-directview", default=False,
               help="if True, ignore sky data and use daylight factors directly")
 @clk.shared_decs(clk.command_decs(raytraverse.__version__, wrap=True))
 def images(ctx, sensors=None, sdirs=None, viewangle=180., skymask=None,
            basename="results", res=800, interpolate=None, namebyindex=False,
            simtype="2comp", resuntol=5.0, blursun=False, resampleview=False,
-           directview=False, maskfull=True, resamprad=0.0, **kwargs):
+           directview=False, maskfull=True, resamprad=0.0, bandwidth=20,
+           **kwargs):
     """render images
 
     Prerequisites:
@@ -858,7 +872,8 @@ def images(ctx, sensors=None, sdirs=None, viewangle=180., skymask=None,
                                           interp=interpolate, prefix=basename,
                                           namebyindex=namebyindex,
                                           suntol=resuntol, blursun=blursun,
-                                          resamprad=resamprad))
+                                          resamprad=resamprad,
+                                          bandwidth=bandwidth))
         result = np.concatenate(result)
     elif sdirs is None:
         raise ValueError("if sensors do not have directions, sdirs cannot be "
@@ -867,7 +882,8 @@ def images(ctx, sensors=None, sdirs=None, viewangle=180., skymask=None,
         result = itg.make_images(sd, sensors, sdirs, viewangle=viewangle,
                                  res=res, interp=interpolate, prefix=basename,
                                  namebyindex=namebyindex, suntol=resuntol,
-                                 blursun=blursun,  resamprad=resamprad)
+                                 blursun=blursun,  resamprad=resamprad,
+                                 bandwidth=bandwidth)
     for d in result:
         print(d)
     sd.mask = None
