@@ -65,7 +65,7 @@ class Integrator(object):
 
     def make_images(self, skydata, points, vm, viewangle=180., res=512,
                     interp=False, prefix="img", namebyindex=False, suntol=10.0,
-                    blursun=False, resamprad=0.0):
+                    blursun=False, resamprad=0.0, bandwidth=10):
         """see namebyindex for file naming conventions
 
         Parameters
@@ -131,7 +131,7 @@ class Integrator(object):
                                      mask_kwargs=mask_kwargs, vms=vms, res=res,
                                      interp=interp, prefix=prefix,
                                      suntol=suntol, blursun=blursun,
-                                     resamprad=resamprad)
+                                     resamprad=resamprad, bandwidth=bandwidth)
         return sorted([i for j in outfs for i in j])
 
     def _echunk(self, evalfunc, esize, csize, skydata, points, vm, **kwargs):
@@ -142,13 +142,14 @@ class Integrator(object):
         os.remove(rbase)
         d = np.linspace(0, len(skydata.maskindices),
                         int(esize/csize) + 2).astype(int)
-        self.scene.log(self, f"breaking evaluation into {len(d)} chunks,"
+        self.scene.log(self, f"breaking evaluation into {len(d) - 1} chunks,"
                              f" writing temporary results to {rbase}_XX.npz"
                        , True)
         slices = [slice(d[i], d[i + 1], 1) for i in range(len(d) - 1)]
         omask = np.copy(skydata.mask)
         for i, slc in enumerate(slices):
-            self.scene.log(self, f"evaluating part {i + 1} of {len(d)}", True)
+            self.scene.log(self, f"evaluating part {i + 1} of {len(slices)}",
+                           True)
             skydata.mask = skydata.maskindices[slc]
             lr = evalfunc(skydata, points, vm, emax=-1, **kwargs)
             skydata.mask = omask
@@ -266,7 +267,7 @@ class Integrator(object):
                     ResultAxis(points, "point"),
                     ResultAxis([v.dxyz for v in vms], "view"),
                     ResultAxis(list(ometrics) + dinfo, "metric"))
-            lr = LightResult(fields, *axes)
+            lr = LightResult(fields, *axes, boundary=self.lightplanes[0].pm)
         return lr
 
     def zonal_evaluate(self, skydata, pm, vm, viewangle=180.,
@@ -362,7 +363,7 @@ class Integrator(object):
             fvecs = np.broadcast_to(all_vecs[:, None, 3:], oshape + (3,))
             fields = np.concatenate((fvecs, areas, fields), axis=-1)
             fields = np.split(fields, strides)
-            lr = ZonalLightResult(fields, *axes)
+            lr = ZonalLightResult(fields, *axes, boundary=pm)
         return lr
 
     @staticmethod
