@@ -19,13 +19,14 @@ class SensorIntegrator(Integrator):
     ----------
     lightplanes: Sequence[raytraverse.lightfield.SensorPlaneKD]
     ptype: Sequence[str]
-        raises
         matching order of lightplanes, requires one for each:
+
             - "sky": represents sky with nsrcs = skydata
             - "skysun": represents sky+sun with nsrcs = skydata
             - "patch": represents sun contribution as patch
             - "sun": sun contribution
             - "fixed": does not respond to skydata (electric lighting)
+
     factors: Sequence[int], optional
         values, for each light plane to scale contribution of eeach light plane
         for example, provide (1, -1, 1) for ptype: ("skysun", "patch", "sun")
@@ -136,7 +137,7 @@ class SensorIntegrator(Integrator):
                 ResultAxis(apoints, "point"),
                 ResultAxis(sensors, "view"),
                 ResultAxis(["illum"] + dinfo, "metric"))
-        lr = LightResult(fields, *axes)
+        lr = LightResult(fields, *axes, boundary=self.lightplanes[0].pm)
         return lr
 
     def zonal_evaluate(self, skydata, pm, vm=None, datainfo=False,
@@ -219,7 +220,7 @@ class SensorIntegrator(Integrator):
         fvecs = np.broadcast_to(all_vecs[:, None, 3:], oshape + (3,))
         fields = np.concatenate((fvecs, areas, fields), axis=-1)
         fields = np.split(fields, strides)
-        return ZonalLightResult(fields, *axes)
+        return ZonalLightResult(fields, *axes, boundary=pm)
 
     def _evaluate_chunk(self, dsmtx, sunmask, suns, pts, sundata, skarea):
         result = self._unmask_data(dsmtx, sunmask, suns, pts, sundata, skarea)
