@@ -36,7 +36,10 @@ class ResultAxis(object):
             return np.asarray([(i, ) for i in self.values])
 
     def index(self, i):
-        return np.squeeze(np.where(self.values == i))
+        idx = np.squeeze(np.where(self.values == i))
+        if idx.size == 0:
+            raise IndexError(f"'{i}' not in ResultAxis '{self.name}'")
+        return idx
 
     @property
     def cols(self):
@@ -88,8 +91,9 @@ class LightResult(object):
         axis information
     """
 
-    def __init__(self, data, *axes):
+    def __init__(self, data, *axes, boundary=None):
         self._file = None
+        self.boundary = boundary
         if not hasattr(data, "shape") and type(data) not in (list, tuple):
             if os.path.isfile(data):
                 self._file = data
@@ -103,6 +107,20 @@ class LightResult(object):
                              f"{len(self.data.shape)} axes arguments.")
         self._names = [a.name for a in axes]
 
+    @property
+    def boundary(self):
+        return self._boundary
+
+    @boundary.setter
+    def boundary(self, b):
+        if b is None or (hasattr(b, "__len__") and len(b) == 0):
+            self._boundary = None
+        else:
+            try:
+                self._boundary = b.borders()
+            except AttributeError:
+                self._boundary = PlanMapper(b).borders()
+
     @property
     def data(self):
         return self._data
@@ -132,10 +150,15 @@ class LightResult(object):
             names = result['names']
             axes = tuple([ResultAxis(result[f"arr_{i}"], n)
                           for i, n in enumerate(names)])
+            bkeys = [i for i in result.keys() if i[0:4] == "bnd_"]
+            self.boundary = [result[i] for i in bkeys]
         return data, axes
 
     def write(self, file, compressed=True):
         kws = dict(data=self.data, names=self.names)
+        if self.boundary is not None:
+            for i in range(len(self.boundary)):
+                kws[f"bnd_{i}"] = self.boundary[i]
         args = [a.values for a in self.axes]
         if compressed:
             np.savez_compressed(file, *args, **kws)
@@ -184,13 +207,19 @@ class LightResult(object):
         outaxes, filters = self._merge_axes(*lrs, axis=axis)
         oi = self._index(axis)
         data = self.data
+        boundary = self.boundary
         for lr, f, in zip(lrs, filters):
             if np.all(f):
                 od = lr.data
             else:
                 od = np.compress(f, lr.data, axis=oi)
             data = np.concatenate([data, od], axis=oi)
-        return LightResult(data, *outaxes)
+            if axis == "point":
+                try:
+                    boundary += lr.boundary
+                except TypeError:
+                    boundary = None
+        return LightResult(data, *outaxes, boundary=boundary)
 
     def pull(self, *axes, preserve=1, **kwargs):
         """arrange and extract data slices from result.
@@ -369,20 +398,47 @@ class LightResult(object):
         self._print_serial(rt, labels, names, basename, header, rowlabel,
                            skyfill)
 
-    def _pull2hdr_kdplan(self, pm, basename, rt, flabels0, flabels1):
-        img, vecs, mask, mask2, header = pm.init_img(480)
-        pts = np.asarray([tuple(i) for i in self.axis("point").values])[:, 0:3]
-        kd = cKDTree(pts)
+    def _pull2hdr_kdplan(self, pm, basename, rt, flabels0, flabels1,
+                         showsample=False, res=480):
+        img, vecs, mask, mask2, header = pm.init_img(res)
+        pts = self.axis("point").value_array()
+        kd = cKDTree(pts[:, 0:3])
         err, idx = kd.query(vecs[mask])
         for i, la0 in enumerate(flabels0):
             data = rt[..., i]
             for k, (la, d) in enumerate(zip(flabels1, data.T)):
                 img[mask] = d[idx]
-                io.array2hdr(img, f"{basename}_{la}_{la0}.hdr", [header])
+                if showsample:
+                    if len(img.shape) < 3:
+                        img = np.repeat(img[None, ...], 3, 0)
+                    img = pm.add_vecs_to_img(img, kd.data)
+                    io.carray2hdr(img, f"{basename}_{la}_{la0}.hdr", [header])
+                else:
+                    io.array2hdr(img, f"{basename}_{la}_{la0}.hdr", [header])
+
+    def rebase(self, points):
+        paxis = ResultAxis(points, "point")
+        omet = self.axis("metric").values
+        mf = [i for i, v in enumerate(omet) if v not in ('x', 'y', 'z', 'area')]
+        maxis = ResultAxis([omet[i] for i in mf] + ["rebase_err"], "metric")
+
+        pts = self.axis("point").value_array()
+        kd = cKDTree(pts)
+        err, idx = kd.query(points)
+        odata = self.data[:, idx][..., mf]
+        oerr = np.broadcast_to(err[:, None, None], (*odata.shape[:-1], 1))
+        odata = np.concatenate((odata, oerr), axis=-1)
+        lr = LightResult(np.stack(odata), self.axes[0], paxis, self.axes[2],
+                         maxis)
+        return lr
 
     @staticmethod
     def _pull2hdr_sky(skyfill, basename, spd, rt, flabels0, flabels1):
-        if skyfill.skydata.shape[0] % 365 == 0:
+        if skyfill is None:
+            gsort = None
+            gshp = (int(rt.shape[0]/spd), spd)
+            psize = (int(730/gshp[0]), max(5, int(240/gshp[1])))
+        elif skyfill.skydata.shape[0] % 365 == 0:
             gshp = (365, int(skyfill.skydata.shape[0]/365))
             hour = np.arange(skyfill.skydata.shape[0])
             gsort = np.lexsort((-np.mod(hour, gshp[1]), np.floor(hour/gshp[1])))
@@ -401,22 +457,18 @@ class LightResult(object):
             else:
                 data = rt[..., i]
             for k, (la, d) in enumerate(zip(flabels1, data.T)):
-                do = d[gsort].reshape(gshp)
+                try:
+                    do = d[gsort].reshape(gshp)
+                except ValueError:
+                    raise ValueError(f"'pull2hdr' to sky images without sky "
+                                     f"fill requires data that can be reshaped "
+                                     f"to (-1, spd), where spd={spd}.")
                 do = np.repeat(np.repeat(do, psize[1], 1), psize[0], 0)
                 io.array2hdr(do[-1::-1], f"{basename}_{la}_"
                                          f"{la0}.hdr")
 
-    def pull2planhdr(self, imgzone, basename, showsample=False, **kwargs):
-        pm = PlanMapper(imgzone)
-        if "metric" in kwargs and kwargs["metric"] is not None:
-            kwargs["metric"] = np.unique(
-                np.concatenate(([0, 1, 2], kwargs["metric"])))
-        rt, labels, names = self.pull("metric", preserve=2, **kwargs)
-        flabels0 = self.fmt_names(names[-1], labels[-1])
-        flabels1 = self.fmt_names(names[-2], labels[-2])
-        return self._pull2hdr_kdplan(pm, basename, rt, flabels0, flabels1)
-
-    def pull2hdr(self, col, basename, skyfill=None, spd=24, pm=None, **kwargs):
+    def pull2hdr(self, basename, col="metric", skyfill=None, spd=24, pm=None,
+                 res=480, showsample=False, **kwargs):
         rt, labels, names = self.pull(*col, preserve=2, **kwargs)
         flabels0 = self.fmt_names(names[-1], labels[-1])
         flabels1 = self.fmt_names(names[-2], labels[-2])
@@ -427,10 +479,14 @@ class LightResult(object):
                                  "points. make sure non-point axes besides "
                                  "'col' are filtered to a single value")
             if pm is None:
-                pm = PlanMapper(self.axis("point").value_array()[:, 0:3])
-            return self._pull2hdr_kdplan(pm, basename, rt, flabels0, flabels1)
+                if self.boundary is None:
+                    pm = PlanMapper(self.axis("point").value_array()[:, 0:3])
+                else:
+                    pm = PlanMapper(self.boundary)
+            return self._pull2hdr_kdplan(pm, basename, rt, flabels0, flabels1,
+                                         showsample=showsample, res=res)
         if skyfill is None:
-            raise ValueError("'pull2hdr' with 'sky' requires skyfill")
+            pass
         elif rt.shape[0] != skyfill.smtx.shape[0]:
             raise ValueError("SkyData and result do not have the same number "
                              f"of values ({skyfill.smtx.shape[0]} vs. "
