@@ -164,7 +164,7 @@ class SkyMapper(AngularMixin, Mapper):
             if None, use the instance default, if True jitters point samples
             within stratified grid
         level: int, optional
-            sets the resolution of the grid as a power of 2 from ptres
+            sets the resolution of the grid as a power of 2 from sunres
         masked: bool, optional
             apply in_solarbounds before returning
 
@@ -177,7 +177,7 @@ class SkyMapper(AngularMixin, Mapper):
         idx = np.arange(np.product(shape))
         uv = self.idx2uv(idx, shape, jitter)
         if masked:
-            return uv[self.in_solarbounds_uv(uv)]
+            return uv[self.in_solarbounds_uv(uv, level=level)]
         else:
             return uv
 
@@ -189,7 +189,7 @@ class SkyMapper(AngularMixin, Mapper):
         jitter: bool, optional
             jitters weighting of condidate selection (not centered)
         level: int, optional
-            sets the resolution of the grid as a power of 2 from ptres
+            sets the resolution of the grid as a power of 2 from sunres
         masked: bool, optional
             apply in_solarbounds before returning
 
