@@ -127,6 +127,7 @@ nrbins = side * side;
 binl(u, v) : axis(u)*side + axis(v);
 
 { shirley-chiu disk to square (with spherical term) }
+PI : 3.14159265358979323846;
 pi4 : PI/4;
 n = if(Dz, 1, -1);
 r2 = 1 - n*Dz;
@@ -583,13 +584,6 @@ def calc_omega(vecs, pm):
     else:
         scale = 1.
 
-    # pg = pygeos.get_parts([pygeos.polygons(vor.vertices[vor.regions[i]])
-    #                        for i in vor.point_region[:len(vecs)]])
-    # border = pygeos.multipolygons([b[:, 0:2] for b in pm.borders()])
-    # # regions = pygeos.intersection(border, pg)
-    # omega = pygeos.area(pg) * scale
-    # return omega
-
     omega = np.zeros(len(vecs))
     for i in range(len(vecs)):
         region = vor.regions[vor.point_region[i]]
